pub trait Fitter {
// Required method
fn fit(
&self,
finder_positions: Vec<BoundingRect>,
image_width: usize,
image_height: usize,
) -> Result<PerspectiveTransform, &str>;
}Expand description
Given an array of finder candidates positions, evaluate the “correct” perspective transform that maps the image space to the object space.